import { OnInit } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { EntityService } from '../entity.service';
import { SearchHelp } from './search-help';
import * as ɵngcc0 from '@angular/core';
export declare class SearchHelpComponent implements OnInit {
    private fb;
    private entityService;
    isSearchHelpModalShown: boolean;
    isFilterShown: boolean;
    isSelectAllChecked: boolean;
    searchHelp: SearchHelp;
    fuzzySearchTerm: string;
    selectedIndex: number;
    filterFields: any[];
    listFields: any[];
    filterFieldsFormGroup: FormGroup;
    exportControl: any;
    afterExportFn: any;
    listData: any[];
    preSearchHelpParas: {};
    get displaySearchHelpModal(): "none" | "block";
    constructor(fb: FormBuilder, entityService: EntityService);
    ngOnInit(): void;
    /**
     * Open an search help dialog with free style
     * @param searchHelp
     * @param exportControl: An Angular form control which is used to receive the Search Help returned value.
     * @param afterExportFn: Optional. If provided, the function will be executed after the value is returned.
     */
    openSearchHelpModal(searchHelp: SearchHelp, exportControl: any, afterExportFn?: any): void;
    /**
     * Open a search help dialog based on the given entity and one of its relation
     * @param entityID
     * @param relationID
     * @param exportControl: An Angular form control which is used to receive the Search Help returned value.
     * @param readonly: If readonly, then the Search Help cannot return value.
     * @param exportField: Provided only if exportField is given. It uses the data domain to find which attribute should return the value(s).
     For example, attribute "USER" is assigned with Data Domain "USER_ID". When the Search Help dialog pops up on the field 'CREATE_BY',
     it finds the attribute "USER" using the Data Domain "USER_ID",
     and the value of its attribute "USER" is then exported to the field "CREATE_BY".
     * @param afterExportFn: Optional. If provided, the function will be executed after the value is returned.
     */
    openSearchHelpModalByEntity(entityID: string, relationID: string, exportControl: any, readonly: boolean, exportField?: string, domainID?: string, afterExportFn?: any): void;
    /**
     * Open a search help dialog based on the given search help
     * @param searchHelpID
     * @param searchHelpExportField: a field name in the Search Help which is tagged as exported.
     An Search Help can have multiple exported fields, and the field names may be different with the Angular control names.
     Thus, you can choose one Search Help export field name to map with one Angular field control name.
     * @param exportField: An Angular field control name that is to map with the Search Help export field name.
     * @param exportControl: An Angular form control which is used to receive the Search Help returned value.
     * @param readonly: If readonly, then the Search Help cannot return value.
     * @param afterExportFn: Optional. If provided, the function will be executed after the value is returned.
     */
    openSearchHelpModalBySearchHelp(searchHelpID: string, searchHelpExportField: string, exportField: string, exportControl: any, readonly: boolean, afterExportFn?: any): void;
    _isPreviousSearchHelp(currentSearchHelpParas: object): boolean;
    search(): void;
    _generateSearchList(data: object[]): void;
    enterSearch($event: any): void;
    showFilter(): void;
    hideFilter(): void;
    selectAll(): void;
    confirmSelection(): void;
    closeSearchHelpModal(): void;
    static ɵfac: ɵngcc0.ɵɵFactoryDef<SearchHelpComponent, never>;
    static ɵcmp: ɵngcc0.ɵɵComponentDefWithMeta<SearchHelpComponent, "dk-app-search-help", never, {}, {}, never, never>;
}

//# sourceMappingURL=search-help.component.d.ts.map